@@ -229,7 +229,7 @@ namespace OpenBabel
     unsigned int i, j, k, kMax, iMax;
     std::vector<double> vScales(dim, 0);
     double maxVal = 0, dummy = 0;
-    double * pRowi = NULL;
+    double * pRowi = nullptr;
 
     // first find the highest pivot element in each row and store it for implicit scaling
     for (i = 0; i < dim; ++i)
