@@ -36,7 +36,7 @@ class FastSearchFormat : public OBFormat
 {
 public:
 //Register this format type ID
-FastSearchFormat() : fsi(NULL)
+FastSearchFormat() : fsi(nullptr)
 {
   OBConversion::RegisterFormat("fs",this);
   //Specify the number of option taken by options
@@ -174,7 +174,7 @@ virtual const char* Description() //required
     if(!ObtainTarget(pConv, patternMols, indexname))
       return false;
 
-    bool exactmatch = pConv->IsOption("e",OBConversion::INOPTIONS)!=NULL;// -ae option
+    bool exactmatch = pConv->IsOption("e", OBConversion::INOPTIONS) != nullptr; // -ae option
 
     //Open the datafile and put it in pConv
     //datafile name derived from index file probably won't have a file path
@@ -280,7 +280,7 @@ virtual const char* Description() //required
             pConv->SetOneObjectOnly();
             if(itr != --SeekposMap.rend())
               pConv->SetMoreFilesToCome();//so that not seen as last on output
-            pConv->Convert(NULL,NULL);
+            pConv->Convert(nullptr, nullptr);
           }
       }
 
@@ -343,11 +343,11 @@ virtual const char* Description() //required
   bool FastSearchFormat::WriteChemObject(OBConversion* pConv)
   {
     //Prepares or updates an index file. Called for each molecule indexed
-    bool update = pConv->IsOption("u")!=NULL;
+    bool update = pConv->IsOption("u") != nullptr;
 
     static ostream* pOs;
     static bool NewOstreamUsed;
-    if(fsi==NULL)
+    if (fsi == nullptr)
       {
 	// Warn that compressed files cannot be used. It's hard to seek
 	// inside of a gzip file.
@@ -380,7 +380,7 @@ virtual const char* Description() //required
         auditMsg += description.substr( 0, description.find('\n') );
         obErrorLog.ThrowError(__FUNCTION__,auditMsg,obAuditMsg);
 
-        FptIndex* pidx=NULL; //used with update
+        FptIndex* pidx = nullptr; //used with update
 
         //if(pOs==&cout) did not work with GUI
         if(!dynamic_cast<ofstream*>(pOs))
@@ -521,7 +521,7 @@ virtual const char* Description() //required
           delete pOs;
 
         //return to starting conditions
-        fsi=NULL;
+        fsi=nullptr;
 
         obErrorLog.StartLogging();
 
