@@ -603,7 +603,7 @@ namespace Smiley {
 
   struct SmartsAtom
   {
-    SmartsAtom() : expr(0), atomClass(0), chiral(0) {}
+    SmartsAtom() : expr(nullptr), atomClass(0), chiral(0) {}
     SmartsAtom(SmartsAtomExpr *expr_, int ac, bool chrl)
         : expr(expr_), atomClass(ac), chiral(chrl) {}
     SmartsAtomExpr *expr;
@@ -2462,7 +2462,7 @@ namespace Smiley {
           if (m_str[m_pos] == '.') {
             if (m_index == 0)
               throw Exception(Exception::SyntaxError, LeadingDot,
-                  "Found dot '.' at begining of pattern", 0, 1);
+                  "Found dot '.' at beginning of pattern", 0, 1);
             if (m_pos + 1 >= m_str.size())
               throw Exception(Exception::SyntaxError, TrailingDot,
                   "Found dor '.' at ending of pattern", m_pos - 1, 1);
