@@ -272,7 +272,7 @@ namespace OpenBabel
   bool STLFormat::WriteMolecule( OBBase* pOb, OBConversion* pConv )
   {
     OBMol* pmol = dynamic_cast< OBMol* >(pOb);
-    if( pmol == 0 ) return false;
+    if (pmol == nullptr) return false;
 
     ostream& os = *pConv->GetOutStream();
 
