@@ -358,7 +358,7 @@ YOBFormat theYOBFormat;
 bool YOBFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
 {
   OBMol* pmol = pOb->CastAndClear<OBMol>();
-  if(pmol==NULL)
+  if (pmol == nullptr)
       return false;
 
   //Define some references so we can use the old parameter names
@@ -398,7 +398,7 @@ bool YOBFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
   mob_invid(&id);
   atoms=uint32le(mob[MOB_ATOMS]);
   srcatom=mob_start(mob);
-  res=NULL;
+  res=nullptr;
   charged=0;
   for (i=0;i<atoms;i++)
   { /* GET ELEMENT, TYPE AND POSITION */
@@ -473,7 +473,7 @@ bool YOBFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
 bool YOBFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
 {
   OBMol* pmol = dynamic_cast<OBMol*>(pOb);
-  if(pmol==NULL)
+  if (pmol == nullptr)
       return false;
 
   //Define some references so we can use the old parameter names
