@@ -101,7 +101,7 @@ int ffuff(int argc, char* argv[])
     
   OBForceField* pFF = OBForceField::FindForceField("UFF");
 
-  if (pFF == NULL) {
+  if (pFF == nullptr) {
     cerr << "Bail out! Cannot load force field!" << endl;
     return -1; // test failed
   }
@@ -178,7 +178,7 @@ void GenerateEnergies()
 
   OBForceField* pFF = OBForceField::FindForceField("UFF");
 
-  if (pFF == NULL) {
+  if (pFF == nullptr) {
     cerr << "Cannot load force field!" << endl;
     return;
   }
