@@ -2,6 +2,8 @@
 
 #include "obtest.h"
 #include <openbabel/mol.h>
+#include <openbabel/atom.h>
+#include <openbabel/bond.h>
 #include <openbabel/spectrophore.h>
 
 
